@@ -24,6 +24,7 @@ from __future__ import print_function
 import datetime
 import os
 import re
+import sys
 from subprocess import PIPE
 from subprocess import STDOUT
 from subprocess import Popen
@@ -59,7 +60,11 @@ def mTimeVersion(init_file):
     for root, _, files in os.walk(cwd):
         for f in files:
             m = max(os.path.getmtime(os.path.join(root, f)), m)
-    d = datetime.datetime.utcfromtimestamp(m)
+
+    if sys.version_info >= (3, 3):
+        d = datetime.datetime.fromtimestamp(m, datetime.timezone.utc)
+    else:
+        d = datetime.datetime.utcfromtimestamp(m)
     return d.strftime("%Y.%m.%d")
 
 
@@ -75,7 +80,7 @@ def getVersionFromArchiveId(git_archive_id='$Format:%ct %d$'):
         See man gitattributes(5) and git-log(1) (PRETTY FORMATS) for more details.
     """
     # mangle the magic string to make sure it is not replaced by git archive
-    if not git_archive_id.startswith('$For''mat:'):
+    if not git_archive_id.startswith('$For' + 'mat:'):
         # source was modified by git archive, try to parse the version from
         # the value of git_archive_id
 
@@ -86,7 +91,10 @@ def getVersionFromArchiveId(git_archive_id='$Format:%ct %d$'):
 
         # archived revision is not tagged, use the commit date
         tstamp = git_archive_id.strip().split()[0]
-        d = datetime.datetime.utcfromtimestamp(int(tstamp))
+        if sys.version_info >= (3, 3):
+            d = datetime.datetime.fromtimestamp(int(tstamp), datetime.timezone.utc)
+        else:
+            d = datetime.datetime.utcfromtimestamp(int(tstamp))
         return d.strftime('%Y.%m.%d')
     return None
 
