@@ -15,12 +15,13 @@
 
 from __future__ import absolute_import
 from __future__ import print_function
-from future.builtins import range
 
 import multiprocessing
 import os
 import shutil
 
+from six.moves import range
+
 from twisted.internet import defer
 from twisted.internet import reactor
 from twisted.internet import task
